@@ -4,7 +4,7 @@ import argparse
 import datetime
 import json
 import logging
-import sys
+import typing
 from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path
@@ -18,7 +18,7 @@ from dataclasses_json import DataClassJsonMixin
 
 import annoworkcli
 from annoworkcli.actual_working_time.list_actual_working_time import ListActualWorkingTime
-from annoworkcli.common.cli import COMMAND_LINE_ERROR_STATUS_CODE, OutputFormat, build_annoworkapi, get_list_from_args
+from annoworkcli.common.cli import OutputFormat, build_annoworkapi, get_list_from_args
 from annoworkcli.common.utils import print_csv, print_json
 
 logger = logging.getLogger(__name__)
@@ -44,7 +44,9 @@ class ActualWorkingHoursDaily(DataClassJsonMixin):
     user_id: str
     username: str
     actual_working_hours: float
-    notes: Optional[list]
+    # listでなくtyping.Listを使っている理由：`list`だとPython3.8でデコード時にエラーが発生するため
+    # https://qiita.com/yuji38kwmt/items/ce49efc91bb9b6430437
+    notes: Optional[typing.List[str]]
 
 
 @dataclass
@@ -267,31 +269,27 @@ def main(args):
     start_date: Optional[str] = args.start_date
     end_date: Optional[str] = args.end_date
 
-    command = " ".join(sys.argv[0:3])
     if all(v is None for v in [job_id_list, parent_job_id_list, user_id_list, start_date, end_date]):
-        print(f"{command}: error: '--start_date'や'--job_id'などの絞り込み条件を1つ以上指定してください。", file=sys.stderr)
-        sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
+        logger.warning(
+            "'--start_date'や'--job_id'などの絞り込み条件が1つも指定されていません。" "WebAPIから取得するデータ量が多すぎて、WebAPIのリクエストが失敗するかもしれません。"
+        )
 
     main_obj = ListActualWorkingHoursDaily(annowork_service, args.organization_id)
 
-    if args.input is None:
-        list_actual_working_time_obj = ListActualWorkingTime(
-            annowork_service=annowork_service,
-            organization_id=args.organization_id,
-            timezone_offset_hours=args.timezone_offset,
-        )
-        actual_working_time_list = list_actual_working_time_obj.get_actual_working_times(
-            job_ids=job_id_list,
-            parent_job_ids=parent_job_id_list,
-            user_ids=user_id_list,
-            start_date=args.start_date,
-            end_date=args.end_date,
-            is_set_additional_info=False,
-        )
-        list_actual_working_time_obj.set_additional_info_to_actual_working_time(actual_working_time_list)
-
-    else:
-        actual_working_time_list = get_actual_working_time_list_from_input_file(args.input)
+    list_actual_working_time_obj = ListActualWorkingTime(
+        annowork_service=annowork_service,
+        organization_id=args.organization_id,
+        timezone_offset_hours=args.timezone_offset,
+    )
+    actual_working_time_list = list_actual_working_time_obj.get_actual_working_times(
+        job_ids=job_id_list,
+        parent_job_ids=parent_job_id_list,
+        user_ids=user_id_list,
+        start_date=args.start_date,
+        end_date=args.end_date,
+        is_set_additional_info=False,
+    )
+    list_actual_working_time_obj.set_additional_info_to_actual_working_time(actual_working_time_list)
 
     logger.debug(f"{len(actual_working_time_list)} 件の実績作業時間情報を日ごとに集約します。")
     result: Sequence[ActualWorkingHoursDaily] = create_actual_working_hours_daily_list(
@@ -309,10 +307,11 @@ def main(args):
         result = main_obj.add_parent_job_info(result)
 
     if OutputFormat(args.format) == OutputFormat.JSON:
-        if show_parent_job:
-            dict_result = ActualWorkingHoursDailyWithParentJob.schema().dump(result, many=True)
-        else:
-            dict_result = ActualWorkingHoursDaily.schema().dump(result, many=True)
+        # `.schema().dump(many=True)`を使わない理由：使うと警告が発生するから
+        # https://qiita.com/yuji38kwmt/items/a3625b2011aff1d9901b
+        dict_result = []
+        for elm in result:
+            dict_result.append(elm.to_dict())
 
         print_json(dict_result, is_pretty=True, output=args.output)
     else:
@@ -330,10 +329,6 @@ def parse_args(parser: argparse.ArgumentParser):
         type=str,
         help="対象の組織ID",
     )
-    required_group.add_argument(
-        "--input", type=Path, help="``annoworkcli actual_workign_time list`` コマンドで出力したファイルのパスを指定します。"
-    )
-
     parser.add_argument("-u", "--user_id", type=str, nargs="+", required=False, help="絞り込み対象のユーザID")
 
     # parent_job_idとjob_idの両方を指定するユースケースはなさそうなので、exclusiveにする。
