@@ -27,9 +27,6 @@ from annoworkcli.schedule.list_assigned_hours_daily import ListAssignedHoursDail
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_TO_REPLACE_FOR_VALUE = {numpy.inf: "--", numpy.nan: "--"}
-ROUND_DECIMALS = 2
-
 
 class ShapeType(Enum):
     DETAILS = "details"
@@ -77,11 +74,14 @@ def filter_df(
 
 
 class ReshapeDataFrame:
-    def __init__(self, *, round_decimals: Optional[int] = None, replace_nan_inf_with: Optional[str] = None) -> None:
+    """
+    Args:
+        round_decimals: Noneでなければ、数値列を小数点以下 ``round_decimals`` になるように四捨五入する。
+
+    """
+
+    def __init__(self, *, round_decimals: Optional[int] = None) -> None:
         self.round_decimals = round_decimals
-        self.replace_nan_info = None
-        if replace_nan_inf_with is not None:
-            self.replace_nan_info = {numpy.inf: replace_nan_inf_with, numpy.nan: replace_nan_inf_with}
 
     def format_df(self, df: pandas.DataFrame, value_columns: Optional[list[str]] = None) -> pandas.DataFrame:
         df = df.copy()
@@ -91,12 +91,6 @@ class ReshapeDataFrame:
             else:
                 df = df.round(self.round_decimals)
 
-        if self.replace_nan_info is not None:
-            if value_columns is not None:
-                df[value_columns] = df[value_columns].replace(DEFAULT_TO_REPLACE_FOR_VALUE)
-            else:
-                df = df.replace(DEFAULT_TO_REPLACE_FOR_VALUE)
-
         return df
 
     def get_df_total(self, *, df_actual: pandas.DataFrame, df_assigned: pandas.DataFrame) -> pandas.DataFrame:
@@ -510,14 +504,7 @@ class ReshapeDataFrame:
         df_added_rate = pandas.concat(added_column_list, axis="columns")
         df2 = pandas.concat([df2, df_added_rate], axis="columns")
 
-        # nua,infの置き換えする列を指定したいので、`self.format_df`は使わない
-        if self.round_decimals is not None:
-            df2 = df2.round(self.round_decimals)
-        if self.replace_nan_info is not None:
-            df2.replace(
-                {col: self.replace_nan_info for col in df2.columns if col[1] in ["activity_rate", "monitor_rate"]},
-                inplace=True,
-            )
+        df2 = self.format_df(df2)
 
         df2 = df2[
             [
@@ -673,7 +660,8 @@ class ReshapeWorkingHours:
         self, df_actual: pandas.DataFrame, df_assigned: pandas.DataFrame, shape_type: ShapeType
     ) -> pandas.DataFrame:
 
-        reshape_obj = ReshapeDataFrame(round_decimals=2, replace_nan_inf_with="--")
+        # 見やすくするため、小数点以下2桁になるように四捨五入する
+        reshape_obj = ReshapeDataFrame(round_decimals=2)
         if shape_type == ShapeType.DETAILS:
             df_output = reshape_obj.get_df_details(df_actual=df_actual, df_assigned=df_assigned)
 
@@ -802,18 +790,23 @@ def main(args):
     parent_job_id_list = get_list_from_args(args.parent_job_id)
     job_id_list = get_list_from_args(args.job_id)
     annofab_project_id_list = get_list_from_args(args.annofab_project_id)
-    # "--job_id"と"--annofab_project_id"は排他的なので、job_id_listは上書きする
-    if annofab_project_id_list is not None:
-        job_id_list = main_obj.get_job_id_list_from_af_project_id(annofab_project_id_list)
-
     user_id_list = get_list_from_args(args.user_id)
     start_date = args.start_date
     end_date = args.end_date
 
+    if args.actual_file is None or args.assigned_file is None:
+        if all(v is None for v in [job_id_list, parent_job_id_list, user_id_list, start_date, end_date]):
+            logger.warning(
+                "'--start_date'や'--job_id'などの絞り込み条件が1つも指定されていません。" "WebAPIから取得するデータ量が多すぎて、WebAPIのリクエストが失敗するかもしれません。"
+            )
+
+    # "--job_id"と"--annofab_project_id"は排他的なので、job_id_listは上書きする
+    if annofab_project_id_list is not None:
+        job_id_list = main_obj.get_job_id_list_from_af_project_id(annofab_project_id_list)
+
     shape_type = ShapeType(args.shape_type)
 
     if args.actual_file is not None:
-
         df_actual = get_dataframe_from_input_file(args.actual_file)
     else:
         df_actual = main_obj.get_df_actual(
@@ -955,9 +948,10 @@ def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argpa
     description = (
         "AnnoWorkの実績作業時間とアサイン時間、Annofabの作業時間を比較できるようなCSVファイルに成形します。\n"
         "レポートとして利用できるようにするため、以下を対応しています。\n"
-        " * 小数点以下2桁目まで表示\n"
-        " * 比較対象の比率と差分を表示\n"
-        " * organization_member_idなどGUIに直接関係ない項目は表示しない\n"
+        "\n"
+        "* 小数点以下2桁目まで表示\n"
+        "* 比較対象の比率と差分を表示\n"
+        "* organization_member_idなどGUIに直接関係ない項目は表示しない\n"
     )
 
     parser = annoworkcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=description)
